==> java-client-2.0.0-sources.jar: com/urbanairship/api/channel/Constants.java <==
/*
 * Copyright (c) 2013-2016.  Urban Airship and Contributors
 */

package com.urbanairship.api.channel;

/**
 * Constants
 */
public class Constants {

    // Channel
    public static final String CHANNEL = "channel";
    public static final String DEVICE_TYPE = "device_type";
    public static final String INSTALLED = "installed";
    public static final String OPT_IN = "opt_in";
    public static final String BACKGROUND = "background";
    public static final String PUSH_ADDRESS = "push_address";
    public static final String CREATED = "created";
    public static final String LAST_REGISTRATION = "last_registration";
    public static final String ALIAS = "alias";
    public static final String TAGS = "tags";
    public static final String TAG_GROUPS = "tag_groups";
    // Platform-specific
    public static final String IOS = "ios";
    public static final String BADGE = "badge";
    public static final String QUIETTIME = "quiettime";
    public static final String START = "start";
    public static final String END = "end";
    public static final String TZ = "tz";
    public static final String CHANNEL_ID = "channel_id";
    public static final String WEB = "web";
    public static final String AUTH = "auth";
    public static final String P256DH = "p256dh";
    public static final String SUBSCRIPTION = "subscription";
    public static final String OPEN_CHANNEL = "open";
    public static final String OPEN_PLATFORM_NAME = "open_platform_name";
    public static final String OLD_ADDRESS = "old_address";
    public static final String IDENTIFIERS = "identifiers";

    private Constants() {
    }
}

==> java-client-8.2.0-sources.jar: com/urbanairship/api/channel/Constants.java <==
/*
 * Copyright (c) 2013-2016.  Urban Airship and Contributors
 */

package com.urbanairship.api.channel;

/**
 * Constants
 */
public class Constants {

    // Channel
    public static final String CHANNEL = "channel";
    public static final String DEVICE_TYPE = "device_type";
    public static final String INSTALLED = "installed";
    public static final String OPT_IN = "opt_in";
    public static final String BACKGROUND = "background";
    public static final String PUSH_ADDRESS = "push_address";
    public static final String CREATED = "created";
    public static final String LAST_REGISTRATION = "last_registration";
    public static final String ALIAS = "alias";
    public static final String TAGS = "tags";
    public static final String TAG_GROUPS = "tag_groups";
    public static final String ATTRIBUTES = "attributes";
    // Platform-specific
    public static final String IOS = "ios";
    public static final String BADGE = "badge";
    public static final String QUIETTIME = "quiettime";
    public static final String START = "start";
    public static final String END = "end";
    public static final String TZ = "tz";
    public static final String CHANNEL_ID = "channel_id";
    public static final String WEB = "web";
    public static final String AUTH = "auth";
    public static final String P256DH = "p256dh";
    public static final String SUBSCRIPTION = "subscription";
    public static final String OPEN_CHANNEL = "open";
    public static final String OPEN_PLATFORM_NAME = "open_platform_name";
    public static final String OLD_ADDRESS = "old_address";
    public static final String IDENTIFIERS = "identifiers";
    public static final String ADDRESS = "address";
    public static final String SET_TAGS = "set_tags";
    public static final String TIMEZONE = "timezone";
    public static final String LOCALE_COUNTRY = "locale_country";
    public static final String LOCALE_LANGUAGE = "locale_language";
    public static final String TYPE = "type";
    public static final String EMAIL_ADDRESS = "email_address";
    public static final String UA_ADDRESS = "ua_address";
    public static final String AUDIENCE = "audience";
    public static final String NAMED_USER = "named_user_id";
    public static final String KEY = "key";
    public static final String VALUE = "value";
    public static final String ACTION = "action";
    public static final String TIMESTAMP = "timestamp";

    // Actions
    public static final String ADD_KEY = "add";
    public static final String SET_KEY = "set";
    public static final String REMOVE_KEY = "remove";



    private Constants() {
    }
}
